@@ -2,7 +2,7 @@ import os
 
 initpy = '''import json
 
-functionformat = "def {funcname}():\n"
+functionformat = def {funcname}():\n"
 textformat = "\tprint(\"{text}\")\n\tinput()\n"
 
 f = open("engine/textdump.json", "rt")
